@@ -15,7 +15,9 @@ class TestCommand < JekyllUnitTest
     context "when fatal error occurs" do
       should "exit with non-zero error code" do
         site = Object.new
-        def site.process; raise Jekyll::Errors::FatalException; end
+        def site.process
+          raise Jekyll::Errors::FatalException
+        end
         error = assert_raises(SystemExit) { Command.process_site(site) }
         refute_equal 0, error.status
       end
